@@ -1,5 +1,5 @@
 #
-# $Id: Message.pm,v 1.24 2001/08/06 23:47:06 gisle Exp $
+# $Id: Message.pm,v 1.16 1996/09/18 12:14:39 aas Exp $
 
 package HTTP::Message;
 
@@ -7,12 +7,6 @@ package HTTP::Message;
 
 HTTP::Message - Class encapsulating HTTP messages
 
-=head1 SYNOPSIS
-
- package HTTP::Request;  # or HTTP::Response
- require HTTP::Message;
- @ISA=qw(HTTP::Message);
-
 =head1 DESCRIPTION
 
 A C<HTTP::Message> object contains some headers and a content (body).
@@ -20,9 +14,7 @@ The class is abstract, i.e. it only used as a base class for
 C<HTTP::Request> and C<HTTP::Response> and should never instantiated
 as itself.
 
-The following methods are available:
-
-=over 4
+=head1 METHODS
 
 =cut
 
@@ -31,13 +23,9 @@ The following methods are available:
 require HTTP::Headers;
 require Carp;
 use strict;
-use vars qw($VERSION $AUTOLOAD);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.24 $ =~ /(\d+)\.(\d+)/);
+use vars qw($AUTOLOAD);
 
-$HTTP::URI_CLASS ||= $ENV{PERL_HTTP_URI_CLASS} || "URI";
-eval "require $HTTP::URI_CLASS"; die $@ if $@;
-
-=item $mess = new HTTP::Message;
+=head2 $mess = new HTTP::Message;
 
 This is the object constructor.  It should only be called internally
 by this library.  External code should construct C<HTTP::Request> or
@@ -52,7 +40,7 @@ sub new
 	Carp::croak("Bad header argument") unless ref $header;
 	$header = $header->clone;
     } else {
-	$header = HTTP::Headers->new;
+	$header = new HTTP::Headers;
     }
     $content = '' unless defined $content;
     bless {
@@ -62,7 +50,7 @@ sub new
 }
 
 
-=item $mess->clone()
+=head2 $mess->clone()
 
 Returns a copy of the object.
 
@@ -71,26 +59,17 @@ Returns a copy of the object.
 sub clone
 {
     my $self  = shift;
-    my $clone = HTTP::Message->new($self->{'_headers'}, $self->{'_content'});
+    my $clone = new HTTP::Message $self->{'_headers'}, $self->{'_content'};
     $clone;
 }
 
-=item $mess->protocol([$proto])
-
-Sets the HTTP protocol used for the message.  The protocol() is a string
-like "HTTP/1.0" or "HTTP/1.1".
-
-=cut
-
-sub protocol { shift->_elem('_protocol',  @_); }
-
-=item $mess->content([$content])
+=head2 $mess->content([$content])
 
 The content() method sets the content if an argument is given.  If no
 argument is given the content is not touched.  In either case the
 previous content is returned.
 
-=item $mess->add_content($data)
+=head2 $mess->add_content($data)
 
 The add_content() methods appends more data to the end of the previous
 content.
@@ -109,7 +88,7 @@ sub add_content
     }
 }
 
-=item $mess->content_ref
+=head2 $mess->content_ref
 
 The content_ref() method will return a reference to content string.
 It can be more efficient to access the content this way if the content
@@ -131,21 +110,7 @@ sub as_string
     "";  # To be overridden in subclasses
 }
 
-=item $mess->headers;
-
-Return the embedded HTTP::Headers object.
-
-=item $mess->headers_as_string([$endl])
-
-Call the HTTP::Headers->as_string() method for the headers in the
-message.
-
-=cut
-
-sub headers            { shift->{'_headers'};                }
-sub headers_as_string  { shift->{'_headers'}->as_string(@_); }
-
-=back
+=head1 HEADER METHODS
 
 All unknown C<HTTP::Message> methods are delegated to the
 C<HTTP::Headers> object that is part of every message.  This allows
@@ -153,19 +118,17 @@ convenient access to these methods.  Refer to L<HTTP::Headers> for
 details of these methods:
 
   $mess->header($field => $val);
-  $mess->scan(\&doit);
+  $mess->scan(&doit);
   $mess->push_header($field => $val);
   $mess->remove_header($field);
 
   $mess->date;
   $mess->expires;
   $mess->if_modified_since;
-  $mess->if_unmodified_since;
   $mess->last_modified;
   $mess->content_type;
   $mess->content_encoding;
   $mess->content_length;
-  $mess->content_language
   $mess->title;
   $mess->user_agent;
   $mess->server;
@@ -173,39 +136,36 @@ details of these methods:
   $mess->referer;
   $mess->www_authenticate;
   $mess->authorization;
-  $mess->proxy_authorization;
   $mess->authorization_basic;
-  $mess->proxy_authorization_basic;
+
+
+=head2 $mess->headers_as_string([$endl])
+
+Call the HTTP::Headers->as_string() method for the headers in the
+message.
 
 =cut
 
+sub headers_as_string  { shift->{'_headers'}->as_string(@_);     }
 
 # delegate all other method calls the the _headers object.
 sub AUTOLOAD
 {
     my $self = shift;
-    my $method = substr($AUTOLOAD, rindex($AUTOLOAD, '::')+2);
-    return if $method eq "DESTROY";
-    $self->{'_headers'}->$method(@_);
+    #print STDERR "DELEGATE $AUTOLOAD\n";
+    return if $AUTOLOAD =~ /::DESTROY$/;
+    $AUTOLOAD =~ s/^(\w+::)+//;  # Remove the package name.
+    # Pass the message to the delegate.
+    $self->{'_headers'}->$AUTOLOAD(@_);
 }
 
 # Private method to access members in %$self
 sub _elem
 {
-    my $self = shift;
-    my $elem = shift;
+    my($self, $elem, $val) = @_;
     my $old = $self->{$elem};
-    $self->{$elem} = $_[0] if @_;
+    $self->{$elem} = $val if defined $val;
     return $old;
 }
 
 1;
-
-=head1 COPYRIGHT
-
-Copyright 1995-1997 Gisle Aas.
-
-This library is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
-
-=cut
