@@ -1,4 +1,4 @@
-# $Id: RobotRules.pm,v 1.21 2000/04/07 20:17:54 gisle Exp $
+# $Id: RobotRules.pm,v 1.11 1996/09/30 11:45:10 aas Exp $
 
 package WWW::RobotRules;
 
@@ -30,30 +30,29 @@ WWW::RobotsRules - Parse robots.txt files
 
 =head1 DESCRIPTION
 
-This module parses a F</robots.txt> file as specified in
+This module parses a F<robots.txt> file as specified in
 "A Standard for Robot Exclusion", described in
-<http://info.webcrawler.com/mak/projects/robots/norobots.html>
-Webmasters can use the F</robots.txt> file to disallow conforming
-robots access to parts of their web site.
+<URL:http://info.webcrawler.com/mak/projects/robots/norobots.html>
+Webmasters can use the F<robots.txt> file to disallow conforming
+robots access to parts of their WWW server.
 
 The parsed file is kept in the WWW::RobotRules object, and this object
-provides methods to check if access to a given URL is prohibited.  The
-same WWW::RobotRules object can parse multiple F</robots.txt> files.
+provide methods to check if access to a given URL is prohibited.  The
+same WWW::RobotRules object can parse multiple F<robots.txt> files.
 
-The following methods are provided:
-
-=over 4
+=head1 METHODS
 
 =cut
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.21 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 sub Version { $VERSION; }
 
+
+use URI::URL ();
 use strict;
-use URI ();
 
 
-=item $rules = WWW::RobotRules->new($robot_name)
+=head2 $rules = new WWW::RobotRules 'MOMspider/1.0'
 
 This is the constructor for WWW::RobotRules objects.  The first 
 argument given to new() is the name of the robot. 
@@ -73,7 +72,7 @@ sub new {
 }
 
 
-=item $rules->parse($robot_txt_url, $content, $fresh_until)
+=head2 $rules->parse($url, $content, $fresh_until)
 
 The parse() method takes as arguments the URL that was used to
 retrieve the F</robots.txt> file, and the contents of the file.
@@ -81,9 +80,10 @@ retrieve the F</robots.txt> file, and the contents of the file.
 =cut
 
 sub parse {
-    my($self, $robot_txt_uri, $txt, $fresh_until) = @_;
-    $robot_txt_uri = URI->new("$robot_txt_uri");
-    my $netloc = $robot_txt_uri->authority;
+    my($self, $url, $txt, $fresh_until) = @_;
+
+    $url = new URI::URL $url unless ref($url);	# make it URL
+    my $netloc = $url->netloc;
 
     $self->clear_rules($netloc);
     $self->fresh_until($netloc, $fresh_until || (time + 365*24*3600));
@@ -94,20 +94,11 @@ sub parse {
     my @me_disallowed = ();	# rules disallowed for me
     my @anon_disallowed = ();	# rules disallowed for *
 
-    # blank lines are significant, so turn CRLF into LF to avoid generating
-    # false ones
-    $txt =~ s/\015\012/\012/g;
+    for(split(/\n/, $txt)) {
+	s/\015$//g;
+	s/\s*\#.*//;
 
-    # split at \012 (LF) or \015 (CR) (Mac text files have just CR for EOL)
-    for(split(/[\012\015]/, $txt)) {
-
-	# Lines containing only a comment are discarded completely, and
-        # therefore do not indicate a record boundary.
-	next if /^\s*\#/;
-
-	s/\s*\#.*//;        # remove comments at end-of-line
-
-	if (/^\s*$/) {	    # blank line
+	if (/^\s*$/) {		# blank line
 	    last if $is_me; # That was our record. No need to read the rest.
 	    $is_anon = 0;
 	}
@@ -133,17 +124,7 @@ sub parse {
 	    my $disallow = $1;
 	    $disallow =~ s/\s+$//;
 	    if (length $disallow) {
-		my $ignore;
-		eval {
-		    my $u = URI->new_abs($disallow, $robot_txt_uri);
-		    $ignore++ if $u->scheme ne $robot_txt_uri->scheme;
-		    $ignore++ if lc($u->host) ne lc($robot_txt_uri->host);
-		    $ignore++ if $u->port ne $robot_txt_uri->port;
-		    $disallow = $u->path_query;
-		    $disallow = "/" unless length $disallow;
-		};
-		next if $@;
-		next if $ignore;
+		$disallow = URI::URL->new($disallow, $url)->full_path;
 	    }
 
 	    if ($is_me) {
@@ -172,25 +153,26 @@ sub parse {
 #
 sub is_me {
     my($self, $ua) = @_;
-    my $me = $self->agent;
+    my $me = $self->{'ua'};
     return index(lc($ua), lc($me)) >= 0;
 }
 
-=item $rules->allowed($uri)
+=head2 $rules->allowed($url)
 
 Returns TRUE if this robot is allowed to retrieve this URL.
 
 =cut
 
 sub allowed {
-    my($self, $uri) = @_;
-    $uri = URI->new("$uri");
-    my $netloc = $uri->authority;
+    my($self, $url) = @_;
+    $url = URI::URL->new($url) unless ref $url;	# make it URL
+
+    my $netloc = $url->netloc;
 
     my $fresh_until = $self->fresh_until($netloc);
     return -1 if !defined($fresh_until) || $fresh_until < time;
 
-    my $str = $uri->path_query;
+    my $str = $url->full_path;
     my $rule;
     for $rule ($self->rules($netloc)) {
 	return 1 unless length $rule;
@@ -215,7 +197,7 @@ package WWW::RobotRules::InCore;
 use vars qw(@ISA);
 @ISA = qw(WWW::RobotRules);
 
-=item $rules->agent([$name])
+=head2 $rules->agent([$name])
 
 Get/set the agent name. NOTE: Changing the agent name will clear the robots.txt
 rules and expire times out of the cache.
@@ -237,8 +219,9 @@ sub visit {
     my($self, $netloc, $time) = @_;
     $time ||= time;
     $self->{'loc'}{$netloc}{'last'} = $time;
+    
     my $count = \$self->{'loc'}{$netloc}{'count'};
-    if (!defined $$count) {
+    if (defined $$count) {
 	$$count = 1;
     } else {
 	$$count++;
@@ -293,6 +276,7 @@ sub dump
     for (keys %{$self->{'loc'}}) {
 	my @rules = $self->rules($_);
 	print "$_: ", join("; ", @rules), "\n";
+	
     }
 }
 
@@ -300,13 +284,11 @@ sub dump
 
 __END__
 
-=back
-
 =head1 ROBOTS.TXT
 
 The format and semantics of the "/robots.txt" file are as follows
 (this is an edited abstract of
-<http://info.webcrawler.com/mak/projects/robots/norobots.html>):
+<URL:http://info.webcrawler.com/mak/projects/robots/norobots.html>):
 
 The file consists of one or more records separated by one or more
 blank lines. Each record contains lines of the form
@@ -336,11 +318,13 @@ starts with this value will not be retrieved
 
 =back
 
-=head1 ROBOTS.TXT EXAMPLES
+=head2 Examples
 
 The following example "/robots.txt" file specifies that no robots
 should visit any URL starting with "/cyberworld/map/" or "/tmp/":
 
+  # robots.txt for http://www.site.com/
+
   User-agent: *
   Disallow: /cyberworld/map/ # This is an infinite virtual URL space
   Disallow: /tmp/ # these will soon disappear
@@ -349,6 +333,8 @@ This example "/robots.txt" file specifies that no robots should visit
 any URL starting with "/cyberworld/map/", except the robot called
 "cybermapper":
 
+  # robots.txt for http://www.site.com/
+
   User-agent: *
   Disallow: /cyberworld/map/ # This is an infinite virtual URL space
 
